@@ -4,7 +4,7 @@ import json
 import logging
 import rich_click as click
 import yaml
-from cli import cli
+import cisco
 from pathlib import Path
 from gtts import gTTS
 from rich import print_json
